@@ -108,7 +108,7 @@ class Legend(object):
 		return wrapper
 
 	@draw
-	def draw_line(self, offset, linespacing, *args, **kwargs):
+	def draw_line(self, offset, linespacing=1, *args, **kwargs):
 		"""
 		Draw a line legend for the given label.
 		Any additional arguments and keyword arguments are provided to the plotting function.
@@ -120,7 +120,7 @@ class Legend(object):
 		figure = self.drawable.figure
 		axis = self.drawable.axis
 
-		line = lines.Line2D([ offset, offset + 0.025 ], [ 1 + linespacing / 2. ] * 2,
+		line = lines.Line2D([ offset, offset + 0.0125 ], [ 1 + linespacing / 2. ] * 2,
 							transform=axis.transAxes, *args, **kwargs)
 		line.set_clip_on(False)
 		axis.add_line(line)
@@ -128,7 +128,7 @@ class Legend(object):
 		return line
 
 	@draw
-	def draw_arrow(self, offset, linespacing, *args, **kwargs):
+	def draw_arrow(self, offset, linespacing=1, *args, **kwargs):
 		"""
 		Draw an arrow legend for the given label.
 		Any additional arguments and keyword arguments are provided to the plotting function.
@@ -149,7 +149,7 @@ class Legend(object):
 		return arrow
 
 	@draw
-	def draw_point(self, offset, linespacing, *args, **kwargs):
+	def draw_point(self, offset, linespacing=1, *args, **kwargs):
 		"""
 		Draw a scatter point legend for the given label.
 		Any additional arguments and keyword arguments are provided to the plotting function.
